@@ -9,8 +9,9 @@ use Plack::Response;
 use Scope::Guard ();
 use Time::HiRes qw(alarm time);
 use Carp qw(croak);
+use HTTP::Status qw(HTTP_GATEWAY_TIMEOUT);
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub prepare_app {
     my $self = shift;
@@ -70,7 +71,7 @@ sub call {
     } or do {
         my $request        = Plack::Request->new($env);
 
-        my $response = Plack::Response->new(408);
+        my $response = Plack::Response->new(HTTP_GATEWAY_TIMEOUT);
         if ( my $build_response_coderef = $self->response ) {
             $build_response_coderef->($response);
         }
@@ -100,7 +101,7 @@ Plack::Middleware::Timeout
 
     Plack::Middleeare::Timeout->wrap(
         $app,
-        timeout  => sub { ... } || 120,
+        timeout  => 120,
         # optional callback to set the custom response 
         response => sub {
             my ($response_obj) = @_;
@@ -125,11 +126,11 @@ Timeout any plack requests at an arbitrary time.
 
 =item timeout
 
-Numeric value accepted by subroutine defined in Time::HiRes::alarm, default 120 seconds.
+Numeric value accepted by subroutine defined in Time::HiRes::alarm, default: 120 seconds.
 
 =item response
 
-Optional subroutine which will be exeuted when timeout is reached. The subref receives a Plack::Response object as argument. If the response subref isn't defined, we resolve to emitting a warning: 
+Optional subroutine which will be exeuted when timeout is reached. The subref receives a Plack::Response object as argument. If the response subref isn't defined, we resolve to emitting a warning:
 
 =over
 
@@ -137,6 +138,8 @@ Optional subroutine which will be exeuted when timeout is reached. The subref re
 
 =back
 
+and return a response code 504 (HTTP_GATEWAY_TIMEOUT).
+
 =item soft_timeout
 
 Same as timeout, except this value will be checked after the call to the app has completed. See also C<on_soft_timeout> below.
